Detailed Guides
```````````````

This section is new and evolving.  The idea here is to explore particular use cases in greater depth and provide a more "top down" explanation of some basic features.

.. toctree::
   :maxdepth: 1

   guide_aci
   guide_aws
   guide_azure
   guide_rax
   guide_gce
   guide_cloudstack
   guide_vagrant
   guide_rolling_upgrade
   guide_docker
   guide_packet
   guide_vmware

Pending topics may include: Docker, Jenkins, Google Compute Engine, Linode/DigitalOcean, Continuous Deployment, and more.
